@@ -10,8 +10,12 @@ class Permutation(object):
         """
         A constructor of Permutation class which creates a new list and assigns integer
         numbers starting from 0 to given input n.
-        :param n: n of permutation n!
-        """
+
+        Parameters
+        ----------
+         n: int
+            integer input.
+         """
         self.__n = n
         self.__a = []
         for i in range(n):
@@ -20,14 +24,22 @@ class Permutation(object):
     def get(self) -> list:
         """
         The get method returns the list a.
-        :return: a
+
+        Returns
+        ----------
+        list
+            a
         """
         return self.__a
 
     def next(self) -> bool:
         """
-        The next method generates next permutation for the list a.
-        :return: true if next permutation is possible, false otherwise.
+         The next method generates next permutation for the list a.
+
+        Returns
+        ----------
+        boolean
+            true if next permutation is possible, false otherwise.
         """
         i = self.__n - 2
         while i >= 0 and self.__a[i] >= self.__a[i + 1]:
@@ -45,3 +57,6 @@ class Permutation(object):
             k = k + 1
             j = j - 1
         return True
+
+    def __repr__(self):
+        return f"{self.__a}"
