@@ -5,9 +5,15 @@ class Swap(object):
         """
         The swap method takes a list and two integer numbers i, j. And interchange the given array's
         items at index i and index j.
-        :param array: Array of elements
-        :param i: first index to swap.
-        :param j: second index to change.
+
+        Parameters
+        ----------
+        array : list
+            input
+        i : int
+            first index to swap.
+        j : int
+            second index to change.
         """
         t = array[i]
         array[i] = array[j]
